@@ -177,8 +177,6 @@ public:
       return ExtensionID::SPV_INTEL_fpga_cluster_attributes;
     case DecorationFuseLoopsInFunctionINTEL:
       return ExtensionID::SPV_INTEL_loop_fuse;
-    case internal::DecorationCallableFunctionINTEL:
-      return ExtensionID::SPV_INTEL_fast_composite;
     case DecorationMathOpDSPModeINTEL:
       return ExtensionID::SPV_INTEL_fpga_dsp_control;
     case DecorationInitiationIntervalINTEL:
@@ -214,8 +212,8 @@ public:
       return ExtensionID::SPV_INTEL_fpga_latency_control;
     case DecorationFPMaxErrorDecorationINTEL:
       return ExtensionID::SPV_INTEL_fp_max_error;
-    case internal::DecorationCacheControlLoadINTEL:
-    case internal::DecorationCacheControlStoreINTEL:
+    case DecorationCacheControlLoadINTEL:
+    case DecorationCacheControlStoreINTEL:
       return ExtensionID::SPV_INTEL_cache_controls;
     default:
       return {};
@@ -927,32 +925,31 @@ public:
 class SPIRVDecorateCacheControlLoadINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVDecorateCacheControlLoadINTEL
-  SPIRVDecorateCacheControlLoadINTEL(
-      SPIRVEntry *TheTarget, SPIRVWord CacheLevel,
-      spv::internal::LoadCacheControlINTEL CacheControl)
-      : SPIRVDecorate(spv::internal::DecorationCacheControlLoadINTEL, TheTarget,
-                      CacheLevel, static_cast<SPIRVWord>(CacheControl)){};
+  SPIRVDecorateCacheControlLoadINTEL(SPIRVEntry *TheTarget,
+                                     SPIRVWord CacheLevel,
+                                     LoadCacheControl CacheControl)
+      : SPIRVDecorate(DecorationCacheControlLoadINTEL, TheTarget, CacheLevel,
+                      static_cast<SPIRVWord>(CacheControl)) {}
 
-  SPIRVWord getCacheLevel() const { return Literals.at(0); };
-  spv::internal::LoadCacheControlINTEL getCacheControl() const {
-    return static_cast<spv::internal::LoadCacheControlINTEL>(Literals.at(1));
-  };
+  SPIRVWord getCacheLevel() const { return Literals.at(0); }
+  LoadCacheControl getCacheControl() const {
+    return static_cast<LoadCacheControl>(Literals.at(1));
+  }
 };
 
 class SPIRVDecorateCacheControlStoreINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVDecorateCacheControlStoreINTEL
-  SPIRVDecorateCacheControlStoreINTEL(
-      SPIRVEntry *TheTarget, SPIRVWord CacheLevel,
-      spv::internal::StoreCacheControlINTEL CacheControl)
-      : SPIRVDecorate(spv::internal::DecorationCacheControlStoreINTEL,
-                      TheTarget, CacheLevel,
-                      static_cast<SPIRVWord>(CacheControl)){};
+  SPIRVDecorateCacheControlStoreINTEL(SPIRVEntry *TheTarget,
+                                      SPIRVWord CacheLevel,
+                                      StoreCacheControl CacheControl)
+      : SPIRVDecorate(DecorationCacheControlStoreINTEL, TheTarget, CacheLevel,
+                      static_cast<SPIRVWord>(CacheControl)) {}
 
-  SPIRVWord getCacheLevel() const { return Literals.at(0); };
-  spv::internal::StoreCacheControlINTEL getCacheControl() const {
-    return static_cast<spv::internal::StoreCacheControlINTEL>(Literals.at(1));
-  };
+  SPIRVWord getCacheLevel() const { return Literals.at(0); }
+  StoreCacheControl getCacheControl() const {
+    return static_cast<StoreCacheControl>(Literals.at(1));
+  }
 };
 
 } // namespace SPIRV
