@@ -84,7 +84,8 @@ public:
   bool isTypeEvent() const;
   bool isTypeDeviceEvent() const;
   bool isTypeReserveId() const;
-  bool isTypeFloat(unsigned Bits = 0) const;
+  bool isTypeFloat(unsigned Bits = 0,
+                   unsigned FloatingPointEncoding = FPEncodingMax) const;
   bool isTypeImage() const;
   bool isTypeOCLImage() const;
   bool isTypePipe() const;
@@ -151,6 +152,14 @@ public:
   SPIRVCapVec getRequiredCapability() const override {
     SPIRVCapVec CV;
     switch (BitWidth) {
+    case 4: {
+      if (Module->isAllowedToUseExtension(ExtensionID::SPV_INTEL_int4)) {
+        CV.push_back(CapabilityInt4TypeINTEL);
+        return CV;
+      }
+      CV.push_back(CapabilityArbitraryPrecisionIntegersINTEL);
+      return CV;
+    }
     case 8:
       CV.push_back(CapabilityInt8);
       break;
@@ -171,6 +180,11 @@ public:
   }
   std::optional<ExtensionID> getRequiredExtension() const override {
     switch (BitWidth) {
+    case 4: {
+      if (Module->isAllowedToUseExtension(ExtensionID::SPV_INTEL_int4))
+        return ExtensionID::SPV_INTEL_int4;
+      return ExtensionID::SPV_INTEL_arbitrary_precision_integers;
+    }
     case 8:
     case 16:
     case 32:
@@ -185,7 +199,9 @@ protected:
   _SPIRV_DEF_ENCDEC3(Id, BitWidth, IsSigned)
   void validate() const override {
     SPIRVEntry::validate();
-    assert((BitWidth == 8 || BitWidth == 16 || BitWidth == 32 ||
+    assert(((BitWidth == 4 &&
+             Module->isAllowedToUseExtension(ExtensionID::SPV_INTEL_int4)) ||
+            BitWidth == 8 || BitWidth == 16 || BitWidth == 32 ||
             BitWidth == 64 ||
             Module->isAllowedToUseExtension(
                 ExtensionID::SPV_INTEL_arbitrary_precision_integers)) &&
@@ -201,16 +217,31 @@ class SPIRVTypeFloat : public SPIRVType {
 public:
   static const Op OC = OpTypeFloat;
   // Complete constructor
-  SPIRVTypeFloat(SPIRVModule *M, SPIRVId TheId, unsigned TheBitWidth)
-      : SPIRVType(M, 3, OC, TheId), BitWidth(TheBitWidth) {}
+  SPIRVTypeFloat(SPIRVModule *M, SPIRVId TheId, unsigned TheBitWidth,
+                 unsigned TheFloatingPointEncoding)
+      : SPIRVType(M, 3 + (TheFloatingPointEncoding != FPEncodingMax), OC,
+                  TheId),
+        BitWidth(TheBitWidth), FloatingPointEncoding(TheFloatingPointEncoding) {
+  }
   // Incomplete constructor
-  SPIRVTypeFloat() : SPIRVType(OC), BitWidth(0) {}
+  SPIRVTypeFloat()
+      : SPIRVType(OC), BitWidth(0), FloatingPointEncoding(FPEncodingMax) {}
 
   unsigned getBitWidth() const { return BitWidth; }
 
+  unsigned getFloatingPointEncoding() const { return FloatingPointEncoding; }
+
+  std::optional<ExtensionID> getRequiredExtension() const override {
+    if (isTypeFloat(16, FPEncodingBFloat16KHR))
+      return ExtensionID::SPV_KHR_bfloat16;
+    return {};
+  }
+
   SPIRVCapVec getRequiredCapability() const override {
     SPIRVCapVec CV;
-    if (isTypeFloat(16)) {
+    if (isTypeFloat(16, FPEncodingBFloat16KHR)) {
+      CV.push_back(CapabilityBFloat16TypeKHR);
+    } else if (isTypeFloat(16)) {
       CV.push_back(CapabilityFloat16Buffer);
       auto Extensions = getModule()->getSourceExtension();
       if (std::any_of(Extensions.begin(), Extensions.end(),
@@ -222,14 +253,34 @@ public:
   }
 
 protected:
-  _SPIRV_DEF_ENCDEC2(Id, BitWidth)
+  void encode(spv_ostream &O) const override {
+    assert(WordCount == 3 || WordCount == 4);
+    auto Encoder = getEncoder(O);
+    Encoder << Id << BitWidth;
+    if (WordCount == 4)
+      Encoder << FloatingPointEncoding;
+  }
+
+  void decode(std::istream &I) override {
+    assert(WordCount == 3 || WordCount == 4);
+    auto Decoder = getDecoder(I);
+    Decoder >> Id >> BitWidth;
+    if (WordCount == 4)
+      Decoder >> FloatingPointEncoding;
+  }
+
   void validate() const override {
     SPIRVEntry::validate();
     assert(BitWidth >= 16 && BitWidth <= 64 && "Invalid bit width");
+    assert(
+        (FloatingPointEncoding == FPEncodingMax ||
+         (BitWidth == 16 && FloatingPointEncoding == FPEncodingBFloat16KHR)) &&
+        "Invalid floating point encoding");
   }
 
 private:
   unsigned BitWidth; // Bit width
+  unsigned FloatingPointEncoding;
 };
 
 class SPIRVTypePointer : public SPIRVType {
@@ -1132,10 +1183,19 @@ public:
   SPIRVTypeCooperativeMatrixKHR();
   _SPIRV_DCL_ENCDEC
   std::optional<ExtensionID> getRequiredExtension() const override {
+    SPIRVType *Ty = this->getCompType();
+    if (Ty->isTypeInt() && static_cast<SPIRVTypeInt *>(Ty)->getBitWidth() == 4)
+      this->getModule()->addExtension(ExtensionID::SPV_INTEL_int4);
     return ExtensionID::SPV_KHR_cooperative_matrix;
   }
   SPIRVCapVec getRequiredCapability() const override {
-    return getVec(CapabilityCooperativeMatrixKHR);
+    auto CV = getVec(CapabilityCooperativeMatrixKHR);
+    if (CompType->isTypeFloat(16, FPEncodingBFloat16KHR))
+      CV.push_back(CapabilityBFloat16CooperativeMatrixKHR);
+    else if (CompType->isTypeInt() &&
+             static_cast<SPIRVTypeInt *>(CompType)->getBitWidth() == 4)
+      CV.push_back(CapabilityInt4CooperativeMatrixINTEL);
+    return CV;
   }
 
   SPIRVType *getCompType() const { return CompType; }
